@@ -1,4 +1,4 @@
-#  Copyright (c) 2007, Enthought, Inc.
+#  (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
 #  License: BSD Style.
 
 # override_editor.py --- Example of overriding a trait
@@ -8,7 +8,7 @@ from traitsui.api import Color, ColorEditor
 
 
 class Polygon(HasTraits):
-    line_color = Trait(Color((0, 0, 0)),
-                       editor=ColorEditor())
+    line_color = Trait(Color((0, 0, 0)), editor=ColorEditor())
+
 
 Polygon().configure_traits()
