@@ -1,6 +1,6 @@
 # -------------------------------------------------------------------------
 #
-#  Copyright (c) 2007, Enthought, Inc.
+#  (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
@@ -39,13 +39,14 @@ def main(root_dir):
 if __name__ == '__main__':
 
     # Validate the command line arguments:
-    if len(sys.argv) != 2:
+    if len(sys.argv) > 2:
         print(usage)
         sys.exit(1)
 
-    root_dir = sys.argv[1]
-    try:
-        main(root_dir)
-    except NameError as e:
-        print(e)
-        print(usage)
+    # Determine the root path to use for the tutorial files:
+    if len(sys.argv) == 2:
+        root_dir = sys.argv[1]
+    else:
+        root_dir = os.getcwd()
+
+    main(root_dir)
