@@ -197,16 +197,6 @@ SEARCHER.skip_file_if(
     lambda: not is_wx(),
     "Only support wx",
 )
-SEARCHER.skip_file_if(
-    os.path.join(DEMO, "Misc", "demo_group_size.py"),
-    is_qt6,
-    "enable tries to import a missing constant. See enthought/enable#891",
-)
-SEARCHER.skip_file_if(
-    os.path.join(DEMO, "Standard_Editors", "VideoEditor_demo.py"),
-    lambda: not is_qt5(),
-    "Only supported on Qt5",
-)
 SEARCHER.skip_file_if(
     os.path.join(TUTORIALS, "view_multi_object.py"),
     lambda: True,
