@@ -1,14 +1,13 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2014, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 """ Tests for the ShadowGroup class.
 """
 
@@ -21,7 +20,6 @@ from traitsui.tests._tools import BaseTestMixin
 
 
 class TestShadowGroup(BaseTestMixin, unittest.TestCase):
-
     def setUp(self):
         BaseTestMixin.setUp(self)
 
@@ -34,7 +32,7 @@ class TestShadowGroup(BaseTestMixin, unittest.TestCase):
         # first.  Initialization order is dependent on dictionary order, which
         # we can't control, so we throw in a good number of other traits to
         # increase the chance that some other trait is set first.
-        shadow_group = ShadowGroup(
+        ShadowGroup(
             label="dummy",
             show_border=True,
             show_labels=True,
